@@ -1,12 +1,12 @@
 //! Tendermint Light Client JavaScript/WASM interface.
 //!
-//! This crate exposes some of the [`tendermint-light-client`] crate's
+//! This crate exposes some of the [`tendermint-light-client-verifier`] crate's
 //! functionality to be used from the JavaScript ecosystem.
 //!
 //! For a detailed example, please see the [`verifier-web` example] in the
 //! repository.
 //!
-//! [`tendermint-light-client`]: https://github.com/informalsystems/tendermint-rs/tree/master/light-client
+//! [`tendermint-light-client-verifier`]: https://github.com/informalsystems/tendermint-rs/tree/master/light-client-verifier
 //! [`verifier-web` example]: https://github.com/informalsystems/tendermint-rs/tree/master/light-client-js/examples/verifier-web
 
 mod utils;
@@ -14,9 +14,9 @@ mod utils;
 use serde::{Deserialize, Serialize};
 use std::time::Duration;
 use tendermint::Time;
-use tendermint_light_client::components::verifier::{ProdVerifier, Verifier};
-use tendermint_light_client::light_client::Options;
-use tendermint_light_client::types::{LightBlock, TrustThreshold};
+use tendermint_light_client_verifier::options::Options;
+use tendermint_light_client_verifier::types::{LightBlock, TrustThreshold};
+use tendermint_light_client_verifier::{ProdVerifier, Verifier};
 use wasm_bindgen::prelude::*;
 use wasm_bindgen::JsValue;
 
